@@ -1,7 +1,7 @@
 package Data::Sah::CoerceCommon;
 
-our $DATE = '2016-09-25'; # DATE
-our $VERSION = '0.019'; # VERSION
+our $DATE = '2016-09-29'; # DATE
+our $VERSION = '0.020'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -18,9 +18,9 @@ my %common_args = (
 
 Some Sah types, like `date`, can be represented in a choice of types in the
 target language. For example, in Perl you can store it as a floating number
-a.k.a. `float(epoch)`, or as a `DateTime` object, or `Time::Moment` object.
-Storing in DateTime can be convenient for date manipulation but requires an
-overhead of loading the module and storing in a bulky format. The choice is
+a.k.a. `float(epoch)`, or as a <pm:DateTime> object, or <pm:Time::Moment>
+object. Storing in DateTime can be convenient for date manipulation but requires
+an overhead of loading the module and storing in a bulky format. The choice is
 yours to make, via this setting.
 
 _
@@ -121,8 +121,8 @@ This routine lists coerce rule modules, filters out unwanted ones, loads the
 rest, filters out old (version < current) modules or ones that are not enabled
 by default. Finally the routine gets the rules out.
 
-This common routine is used by `Data::Sah` compilers, as well as
-`Data::Sah::Coerce` and `Data::Sah::CoerceJS`.
+This common routine is used by <pm:Data::Sah> compilers, as well as
+<pm:Data::Sah::Coerce> and <pm:Data::Sah::CoerceJS>.
 
 _
     args => {
@@ -283,7 +283,7 @@ Data::Sah::CoerceCommon - Common stuffs for Data::Sah::Coerce and Data::Sah::Coe
 
 =head1 VERSION
 
-This document describes version 0.019 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2016-09-25.
+This document describes version 0.020 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2016-09-29.
 
 =head1 FUNCTIONS
 
@@ -296,8 +296,8 @@ This routine lists coerce rule modules, filters out unwanted ones, loads the
 rest, filters out old (version < current) modules or ones that are not enabled
 by default. Finally the routine gets the rules out.
 
-This common routine is used by C<Data::Sah> compilers, as well as
-C<Data::Sah::Coerce> and C<Data::Sah::CoerceJS>.
+This common routine is used by L<Data::Sah> compilers, as well as
+L<Data::Sah::Coerce> and L<Data::Sah::CoerceJS>.
 
 This function is not exported.
 
@@ -356,9 +356,9 @@ To use the default rules but not rules matching /^R/:
 
 Some Sah types, like C<date>, can be represented in a choice of types in the
 target language. For example, in Perl you can store it as a floating number
-a.k.a. C<float(epoch)>, or as a C<DateTime> object, or C<Time::Moment> object.
-Storing in DateTime can be convenient for date manipulation but requires an
-overhead of loading the module and storing in a bulky format. The choice is
+a.k.a. C<float(epoch)>, or as a L<DateTime> object, or L<Time::Moment>
+object. Storing in DateTime can be convenient for date manipulation but requires
+an overhead of loading the module and storing in a bulky format. The choice is
 yours to make, via this setting.
 
 =item * B<compiler>* => I<str>
