@@ -1,7 +1,7 @@
 package Data::Sah::CoerceJS;
 
-our $DATE = '2016-09-25'; # DATE
-our $VERSION = '0.019'; # VERSION
+our $DATE = '2016-09-29'; # DATE
+our $VERSION = '0.020'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,7 +25,7 @@ $SPEC{gen_coercer} = {
     description => <<'_',
 
 This is mostly for testing. Normally the coercion rules will be used from
-`Data::Sah`.
+<pm:Data::Sah>.
 
 _
     args => {
@@ -130,7 +130,7 @@ Data::Sah::CoerceJS - Generate coercer code
 
 =head1 VERSION
 
-This document describes version 0.019 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-09-25.
+This document describes version 0.020 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-09-29.
 
 =head1 SYNOPSIS
 
@@ -162,7 +162,7 @@ something like:
 Generate coercer code.
 
 This is mostly for testing. Normally the coercion rules will be used from
-C<Data::Sah>.
+L<Data::Sah>.
 
 This function is not exported by default, but exportable.
 
